% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/describe_table.R
\name{describe_table}
\alias{describe_table}
\title{Describe a table's metadata, citation, and columns}
\usage{
describe_table(name)
}
\arguments{
\item{name}{Table identifier (e.g., "ukb_ppp.pqtls")}
}
\value{
A named list with name, description, citation, source_url,
license, and columns.
}
\description{
Describe a table's metadata, citation, and columns
}
\examples{
\dontrun{
library(bedrockbio)
info <- describe_table("ukb_ppp.pqtls")
info$name
}

}
