% Generated by roxygen2: do not edit by hand
% Please edit documentation in R/load_table.R
\name{load_table}
\alias{load_table}
\title{Lazily query a table}
\usage{
load_table(name, ...)
}
\arguments{
\item{name}{Table identifier (e.g., "ukb_ppp.pqtls")}

\item{...}{Required partition filters
(e.g., ancestry = "EUR", protein_id = "A0FGR8")}
}
\value{
A lazy \code{tbl} backed by DuckDB, compatible with dplyr verbs.
}
\description{
Lazily query a table
}
\examples{
\dontrun{
library(bedrockbio)
library(dplyr)

df <- load_table(
  "dbsnp.vcf",
  assembly = "GRCh38",
  chromosome = "22"
) |>
  select(rsid, position, ref_allele, alt_allele) |>
  head(5) |>
  collect()
}

}
